pub struct PKToolPickerInkingItem { /* private fields */ }PKToolPickerInkingItem and PKToolPickerItem only.Expand description
A user interface for an inking tool item in PKToolPicker.
See also Apple’s documentation
Implementations
Sourceimpl PKToolPickerInkingItem
impl PKToolPickerInkingItem
Sourcepub unsafe fn initWithInkType(
this: Allocated<Self>,
ink_type: &PKInkType,
) -> Retained<Self>
Available on crate feature PKInkType only.
pub unsafe fn initWithInkType( this: Allocated<Self>, ink_type: &PKInkType, ) -> Retained<Self>
PKInkType only.Create a new tool picker item with a PKInkType.
Parameter inkType: The ink type for the tool.
pub unsafe fn initWithInkType_color( this: Allocated<Self>, ink_type: &PKInkType, color: &NSColor, ) -> Retained<Self>
PKInkType and crate feature objc2-app-kit and macOS only.Sourcepub unsafe fn initWithInkType_width(
this: Allocated<Self>,
ink_type: &PKInkType,
width: CGFloat,
) -> Retained<Self>
Available on crate features PKInkType and objc2-core-foundation only.
pub unsafe fn initWithInkType_width( this: Allocated<Self>, ink_type: &PKInkType, width: CGFloat, ) -> Retained<Self>
PKInkType and objc2-core-foundation only.Create a new tool picker item with a PKInkType.
Parameter inkType: The ink type for the tool.
Parameter width: The width for the tool.
pub unsafe fn initWithInkType_color_width( this: Allocated<Self>, ink_type: &PKInkType, color: &NSColor, width: CGFloat, ) -> Retained<Self>
PKInkType and crate feature objc2-app-kit and crate feature objc2-core-foundation and macOS only.pub unsafe fn initWithInkType_color_width_identifier( this: Allocated<Self>, ink_type: &PKInkType, color: &NSColor, width: CGFloat, identifier: Option<&NSString>, ) -> Retained<Self>
PKInkType and crate feature objc2-app-kit and crate feature objc2-core-foundation and macOS only.pub unsafe fn initWithInkType_color_width_azimuth_identifier( this: Allocated<Self>, ink_type: &PKInkType, color: &NSColor, width: CGFloat, azimuth: CGFloat, identifier: Option<&NSString>, ) -> Retained<Self>
PKInkType and crate feature objc2-app-kit and crate feature objc2-core-foundation and macOS only.Sourcepub unsafe fn inkingTool(&self) -> Retained<PKInkingTool>
Available on crate features PKInkingTool and PKTool only.
pub unsafe fn inkingTool(&self) -> Retained<PKInkingTool>
PKInkingTool and PKTool only.A tool for drawing on a PKCanvasView.
Sourcepub unsafe fn allowsColorSelection(&self) -> bool
pub unsafe fn allowsColorSelection(&self) -> bool
Present color selection UI to the user. Default value is YES.
Sourcepub unsafe fn setAllowsColorSelection(&self, allows_color_selection: bool)
pub unsafe fn setAllowsColorSelection(&self, allows_color_selection: bool)
Setter for allowsColorSelection.
Sourceimpl PKToolPickerInkingItem
Methods declared on superclass PKToolPickerItem.
impl PKToolPickerInkingItem
Methods declared on superclass PKToolPickerItem.
Methods from Deref<Target = PKToolPickerItem>
Sourcepub unsafe fn identifier(&self) -> Retained<NSString>
pub unsafe fn identifier(&self) -> Retained<NSString>
A string that identifies the item in the picker. For example, com.example.myapp.toolpicker.pencil. If multiple items with the same identifier are used to create the picker, only the first instance is used.
Methods from Deref<Target = NSObject>
Sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
Sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Panics
May panic if the object is invalid (which may be the case for objects
returned from unavailable init/new methods).
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());Sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
Sourcepub fn downcast_ref<T>(&self) -> Option<&T>where
T: DowncastTarget,
pub fn downcast_ref<T>(&self) -> Option<&T>where
T: DowncastTarget,
Attempt to downcast the object to a class of type T.
This is the reference-variant. Use Retained::downcast if you want
to convert a retained object to another type.
Mutable classes
Some classes have immutable and mutable variants, such as NSString
and NSMutableString.
When some Objective-C API signature says it gives you an immutable class, it generally expects you to not mutate that, even though it may technically be mutable “under the hood”.
So using this method to convert a NSString to a NSMutableString,
while not unsound, is generally frowned upon unless you created the
string yourself, or the API explicitly documents the string to be
mutable.
See Apple’s documentation on mutability and on
isKindOfClass: for more details.
Generic classes
Objective-C generics are called “lightweight generics”, and that’s because they aren’t exposed in the runtime. This makes it impossible to safely downcast to generic collections, so this is disallowed by this method.
You can, however, safely downcast to generic collections where all the
type-parameters are AnyObject.
Panics
This works internally by calling isKindOfClass:. That means that the
object must have the instance method of that name, and an exception
will be thrown (if CoreFoundation is linked) or the process will abort
if that is not the case. In the vast majority of cases, you don’t need
to worry about this, since both root objects NSObject and
NSProxy implement this method.
Examples
Cast an NSString back and forth from NSObject.
use objc2::rc::Retained;
use objc2_foundation::{NSObject, NSString};
let obj: Retained<NSObject> = NSString::new().into_super();
let string = obj.downcast_ref::<NSString>().unwrap();
// Or with `downcast`, if we do not need the object afterwards
let string = obj.downcast::<NSString>().unwrap();Try (and fail) to cast an NSObject to an NSString.
use objc2_foundation::{NSObject, NSString};
let obj = NSObject::new();
assert!(obj.downcast_ref::<NSString>().is_none());Try to cast to an array of strings.
use objc2_foundation::{NSArray, NSObject, NSString};
let arr = NSArray::from_retained_slice(&[NSObject::new()]);
// This is invalid and doesn't type check.
let arr = arr.downcast_ref::<NSArray<NSString>>();This fails to compile, since it would require enumerating over the array to ensure that each element is of the desired type, which is a performance pitfall.
Downcast when processing each element instead.
use objc2_foundation::{NSArray, NSObject, NSString};
let arr = NSArray::from_retained_slice(&[NSObject::new()]);
for elem in arr {
if let Some(data) = elem.downcast_ref::<NSString>() {
// handle `data`
}
}Trait Implementations
Sourceimpl AsRef<AnyObject> for PKToolPickerInkingItem
impl AsRef<AnyObject> for PKToolPickerInkingItem
Sourceimpl AsRef<NSObject> for PKToolPickerInkingItem
impl AsRef<NSObject> for PKToolPickerInkingItem
Sourceimpl AsRef<PKToolPickerItem> for PKToolPickerInkingItem
impl AsRef<PKToolPickerItem> for PKToolPickerInkingItem
Sourcefn as_ref(&self) -> &PKToolPickerItem
fn as_ref(&self) -> &PKToolPickerItem
Sourceimpl Borrow<AnyObject> for PKToolPickerInkingItem
impl Borrow<AnyObject> for PKToolPickerInkingItem
Sourceimpl Borrow<NSObject> for PKToolPickerInkingItem
impl Borrow<NSObject> for PKToolPickerInkingItem
Sourceimpl Borrow<PKToolPickerItem> for PKToolPickerInkingItem
impl Borrow<PKToolPickerItem> for PKToolPickerInkingItem
Sourcefn borrow(&self) -> &PKToolPickerItem
fn borrow(&self) -> &PKToolPickerItem
Sourceimpl ClassType for PKToolPickerInkingItem
impl ClassType for PKToolPickerInkingItem
Sourceconst NAME: &'static str = "PKToolPickerInkingItem"
const NAME: &'static str = "PKToolPickerInkingItem"
Sourcetype Super = PKToolPickerItem
type Super = PKToolPickerItem
Sourcetype ThreadKind = <<PKToolPickerInkingItem as ClassType>::Super as ClassType>::ThreadKind
type ThreadKind = <<PKToolPickerInkingItem as ClassType>::Super as ClassType>::ThreadKind
Sourceimpl CopyingHelper for PKToolPickerInkingItem
impl CopyingHelper for PKToolPickerInkingItem
Sourcetype Result = PKToolPickerInkingItem
type Result = PKToolPickerInkingItem
Self if the type has no
immutable counterpart. Read moreSourceimpl Debug for PKToolPickerInkingItem
impl Debug for PKToolPickerInkingItem
Sourceimpl Deref for PKToolPickerInkingItem
impl Deref for PKToolPickerInkingItem
Sourceimpl Hash for PKToolPickerInkingItem
impl Hash for PKToolPickerInkingItem
Sourceimpl Message for PKToolPickerInkingItem
impl Message for PKToolPickerInkingItem
Sourceimpl NSCopying for PKToolPickerInkingItem
impl NSCopying for PKToolPickerInkingItem
Sourceimpl NSObjectProtocol for PKToolPickerInkingItem
impl NSObjectProtocol for PKToolPickerInkingItem
Sourcefn isEqual(&self, other: Option<&AnyObject>) -> bool
fn isEqual(&self, other: Option<&AnyObject>) -> bool
Sourcefn hash(&self) -> usize
fn hash(&self) -> usize
Sourcefn isKindOfClass(&self, cls: &AnyClass) -> bool
fn isKindOfClass(&self, cls: &AnyClass) -> bool
Sourcefn is_kind_of<T>(&self) -> bool
fn is_kind_of<T>(&self) -> bool
isKindOfClass directly, or cast your objects with AnyObject::downcast_ref